==> atlantic-commons-0.9.0-sources.jar: org/mule/connectors/atlantic/commons/builder/execution/AbstractExecutionBuilder.java <==
package org.mule.connectors.atlantic.commons.builder.execution;

import org.mule.connectors.atlantic.commons.builder.config.ExecutionConfig;
import org.mule.connectors.atlantic.commons.builder.config.PostExecutionListener;
import org.mule.connectors.atlantic.commons.builder.config.PreExecutionListener;
import org.mule.connectors.atlantic.commons.builder.lambda.function.Function;

import java.util.ArrayList;
import java.util.List;

public class AbstractExecutionBuilder<T, FUNCTION, R> {
    private final FUNCTION executionStrategy;
    private final T executingObject;
    private final ExecutionConfig<T, R> config;
    private final List<Object> params;

    public AbstractExecutionBuilder(T executingObject,
                                    FUNCTION executionStrategy,
                                    ExecutionConfig config) {
        this(executingObject, executionStrategy, config, new ArrayList<>());
    }

    public AbstractExecutionBuilder(T service,
                                    FUNCTION executionStrategy,
                                    ExecutionConfig config,
                                    List<Object> params) {
        this.executionStrategy = executionStrategy;
        this.executingObject = service;
        this.config = config;
        this.params = params;
    }

    protected Function<T, R> onPreExecute(Function<T, R> runningFunction) {
        Function<T, R> executingFunction = runningFunction;
        for (PreExecutionListener<T, R> listener : config.getPreExecutionListeners()) {
            executingFunction = listener.onPreExecute(executingObject, runningFunction, params);
        }
        return executingFunction;
    }

    protected R onPostExecute(R result) {
        R modifiedResult = result;
        for (PostExecutionListener<T, R> listener : config.getPostExecutionListeners()) {
            modifiedResult = listener.onPostExecute(executingObject, params, result);
        }
        return modifiedResult;
    }

    protected FUNCTION getExecutionStrategy() {
        return executionStrategy;
    }

    protected T getExecutingObject() {
        return executingObject;
    }

    protected ExecutionConfig<T, R> getConfig() {
        return config;
    }

    protected List<Object> getParams() {
        return params;
    }
}

==> atlantic-commons-0.9.1-sources.jar: org/mule/connectors/atlantic/commons/builder/execution/AbstractExecutionBuilder.java <==
package org.mule.connectors.atlantic.commons.builder.execution;

import org.mule.connectors.atlantic.commons.builder.config.ExecutionConfig;
import org.mule.connectors.atlantic.commons.builder.config.PreExecutionListener;
import org.mule.connectors.atlantic.commons.builder.lambda.function.Function;

import java.util.ArrayList;
import java.util.List;

public class AbstractExecutionBuilder<T, FUNCTION, R> {
    private final FUNCTION executionStrategy;
    private final T executingObject;
    private final ExecutionConfig<T> config;
    private final List<Object> params;

    public AbstractExecutionBuilder(T executingObject,
                                    FUNCTION executionStrategy,
                                    ExecutionConfig config) {
        this(executingObject, executionStrategy, config, new ArrayList<>());
    }

    public AbstractExecutionBuilder(T service,
                                    FUNCTION executionStrategy,
                                    ExecutionConfig config,
                                    List<Object> params) {
        this.executionStrategy = executionStrategy;
        this.executingObject = service;
        this.config = config;
        this.params = params;
    }

    protected void onPreExecute() {
        config.getPreExecutionListeners().forEach(listener -> listener.onPreExecute(executingObject, params));
    }

    protected FUNCTION getExecutionStrategy() {
        return executionStrategy;
    }

    protected T getExecutingObject() {
        return executingObject;
    }

    protected ExecutionConfig<T> getConfig() {
        return config;
    }

    protected List<Object> getParams() {
        return params;
    }
}
